spawn

Function spawn 

pub fn spawn(session: Session, spec: AutomationSpec) -> AutomationHandle
Start one background automation loop for one prepared session.

Invalid specs do not panic: for example, every == Duration::ZERO returns a handle whose status is immediately terminal with AutomationState::Failed.