pub fn route_server_request(
method: &str,
auto_decline_unknown: bool,
) -> ServerRequestRouteExpand description
Decide whether a server request should be queued or auto-declined. Allocation: none. Complexity: O(1).
pub fn route_server_request(
method: &str,
auto_decline_unknown: bool,
) -> ServerRequestRouteDecide whether a server request should be queued or auto-declined. Allocation: none. Complexity: O(1).