pub struct RuntimeConfig {
pub process: StdioProcessSpec,
pub hooks: RuntimeHookConfig,
pub transport: StdioTransportConfig,
pub supervisor: SupervisorConfig,
pub rpc_response_timeout: Duration,
pub server_requests: ServerRequestConfig,
pub initialize_params: Value,
pub live_channel_capacity: usize,
pub server_request_channel_capacity: usize,
pub event_sink: Option<Arc<dyn EventSink>>,
pub event_sink_channel_capacity: usize,
pub state_projection_limits: StateProjectionLimits,
}Expand description
Full configuration for spawning a Runtime instance.
All fields are set with safe defaults via RuntimeConfig::new.
Override individual fields with builder methods.
Allocation: O(1) except event_sink which may hold heap state.
Fields
process: StdioProcessSpechooks: RuntimeHookConfigtransport: StdioTransportConfigsupervisor: SupervisorConfigrpc_response_timeout: Durationserver_requests: ServerRequestConfiginitialize_params: Valuelive_channel_capacity: usizeserver_request_channel_capacity: usizeevent_sink: Option<Arc<dyn EventSink>>event_sink_channel_capacity: usizestate_projection_limits: StateProjectionLimitsImplementations
Sourceimpl RuntimeConfig
impl RuntimeConfig
Sourcepub fn new(process: StdioProcessSpec) -> Self
pub fn new(process: StdioProcessSpec) -> Self
Create config with safe defaults. Allocation: one Value (JSON object). Complexity: O(1).
Sourcepub fn with_hooks(self, hooks: RuntimeHookConfig) -> Self
pub fn with_hooks(self, hooks: RuntimeHookConfig) -> Self
Override lifecycle hook configuration. Allocation: O(h), h = hook count. Complexity: O(1).
Sourcepub fn with_initialize_capabilities(
self,
capabilities: InitializeCapabilities,
) -> Self
pub fn with_initialize_capabilities( self, capabilities: InitializeCapabilities, ) -> Self
Override initialize capability switches while preserving other init params.