pub fn extract_message_metadata(json: &Value) -> MsgMetadataExpand description
Extract commonly used dispatch metadata in one pass over top-level keys. Allocation: owned method/id strings only when present. Complexity: O(1).
pub fn extract_message_metadata(json: &Value) -> MsgMetadataExtract commonly used dispatch metadata in one pass over top-level keys. Allocation: owned method/id strings only when present. Complexity: O(1).