Module rpc_contract

Module rpc_contract 

Modules

methods
Canonical method catalog shared by facade constants and known-method validation.

Structs

RpcContractDescriptor
Single-source descriptor for one app-server RPC contract method.

Enums

RpcRequestContract
Request-shape rule for one RPC method contract descriptor.
RpcResponseContract
Response-shape rule for one RPC method contract descriptor.
RpcValidationMode
Validation mode for JSON-RPC data integrity checks.

Functions

rpc_contract_descriptor
Contract descriptor for one method, when the method is known.
rpc_contract_descriptors
Canonical RPC contract descriptor list (single source of truth).
validate_rpc_request
Validate outgoing JSON-RPC request payload for one method.
validate_rpc_response
Validate incoming JSON-RPC result payload for one method.