pub fn rpc_contract_descriptor(
method: &str,
) -> Option<&'static RpcContractDescriptor>Expand description
Contract descriptor for one method, when the method is known.
pub fn rpc_contract_descriptor(
method: &str,
) -> Option<&'static RpcContractDescriptor>Contract descriptor for one method, when the method is known.