pub struct TurnStreamCollector { /* private fields */ }Expand description
Shared turn stream collector engine used by runtime prompt and artifact execution flows.
It filters by (thread_id, turn_id), accumulates assistant text, and reports terminal events.
Implementations
Sourceimpl TurnStreamCollector
impl TurnStreamCollector
Sourcepub fn push_envelope(
&mut self,
envelope: &Envelope,
) -> Option<TurnTerminalEvent>
pub fn push_envelope( &mut self, envelope: &Envelope, ) -> Option<TurnTerminalEvent>
Consume one envelope. Returns terminal event when this envelope closes the target turn.
Sourcepub fn is_target_envelope(&self, envelope: &Envelope) -> bool
pub fn is_target_envelope(&self, envelope: &Envelope) -> bool
Whether one envelope belongs to this collector turn target.
Sourcepub fn matching_turn_events(&self) -> usize
pub fn matching_turn_events(&self) -> usize
Number of consumed envelopes that matched the target turn.
Sourcepub fn assistant_text(&self) -> &str
pub fn assistant_text(&self) -> &str
Borrow current collected assistant text.
Sourcepub fn into_assistant_text(self) -> String
pub fn into_assistant_text(self) -> String
Take ownership of collected assistant text.