Modules
- methods
- Canonical method catalog shared by facade constants and known-method validation.
Structs
- RpcContract
Descriptor - Single-source descriptor for one app-server RPC contract method.
Enums
- RpcRequest
Contract - Request-shape rule for one RPC method contract descriptor.
- RpcResponse
Contract - Response-shape rule for one RPC method contract descriptor.
- RpcValidation
Mode - Validation mode for JSON-RPC data integrity checks.
Functions
- rpc_
contract_ descriptor - Contract descriptor for one method, when the method is known.
- rpc_
contract_ descriptors - Canonical RPC contract descriptor list (single source of truth).
- validate_
rpc_ request - Validate outgoing JSON-RPC request payload for one method.
- validate_
rpc_ response - Validate incoming JSON-RPC result payload for one method.